package org.artifactory.addon.retention;

import org.artifactory.addon.Addon;
import org.artifactory.addon.license.EdgeBlockedAddon;
import org.artifactory.api.common.BasicStatusHolder;
import org.artifactory.api.rest.retention.ArtifactRetentionColdRestoreRequest;
import org.artifactory.api.rest.retention.ArtifactRetentionRestoreRequest;
import org.artifactory.aql.api.internal.AqlBase;
import org.artifactory.aql.result.AqlRestResult;
import org.artifactory.descriptor.retention.ArtifactRetentionPolicyDescriptor;
import org.artifactory.descriptor.retention.search.criteria.ArtifactRetentionPolicySearchCriteriaDescriptor;
import org.artifactory.rest.exception.MissingRestAddonException;
import org.artifactory.storage.StorageSummary;

import java.io.IOException;
import java.util.Collections;
import java.util.List;
import java.util.Map;

/**
 * @author Tamar Rosen
 */
@EdgeBlockedAddon
public interface ArtifactRetentionAddon extends Addon {

    default void triggerPolicy(String policyKey, BasicStatusHolder statusHolder) {
        throw new MissingRestAddonException();
    }

    default ArtifactRetentionPolicyModel getPolicy(String policyKey) {
        throw new MissingRestAddonException();
    }

    default ArtifactRetentionPolicyModel addPolicy(String policyKey, ArtifactRetentionPolicyDescriptor policy) {
        throw new MissingRestAddonException();
    }

    default ArtifactRetentionPolicyModel updatePolicy(String policyKey,
            ArtifactRetentionPolicyDescriptor newPolicy) {
        throw new MissingRestAddonException();
    }

    default void deletePolicy(String policyKey) {
        throw new MissingRestAddonException();
    }

    default void restore(ArtifactRetentionRestoreRequest restoreRequest,
            BasicStatusHolder statusHolder) throws IOException {
        throw new MissingRestAddonException();
    }

    default ArtifactRetentionPreviewSummary previewByPolicyKey(String policyKey) {
        throw new MissingRestAddonException();
    }

    default ArtifactRetentionPreviewSummary previewByPolicy(ArtifactRetentionPolicyDescriptor policy) {
        throw new MissingRestAddonException();
    }

    default void executeColdRestore(ArtifactRetentionColdRestoreRequest coldRestoreRequest) {
        throw new MissingRestAddonException();
    }

    default Map<String, String> getCreateBinaryHeaders() {
        return Collections.emptyMap();
    }

    default Map<String, String> getInitiateBinaryRestoreHeaders() {
        return Collections.emptyMap();
    }

    default Map<String, String> getIsBinaryRestoredHeaders() {
        return Collections.emptyMap();
    }

    default List<ArtifactRetentionPolicyModel> getPolicies() {
        throw new MissingRestAddonException();
    }

    default ArtifactRetentionStats getArtifactRetentionStats() {
        return null;
    }

    default boolean isColdInstance() {
        return false;
    }

    default AqlRestResult searchOnColdInstance(String aqlStr, BasicStatusHolder statusHolder) {
        throw new MissingRestAddonException();
    }

    default String generateJFrogColdStorageNamespace() {
        return null;
    }

    default String getJfrogColdStorageArchivingNamespace() {
        return null;
    }

    default List<ArtifactRetentionArchivePolicyStatus> getArchivePoliciesExecutions(Long extractLongEpoch,
            Long extractLongEpoch1, String searchStr) {
        throw new MissingRestAddonException();
    }

    default List<ArtifactRetentionRestorePolicyStatus> getRestorePoliciesExecutions(Long extractLongEpoch,
            Long extractLongEpoch1) {
        throw new MissingRestAddonException();
    }

    default StorageSummary getArchiveStorageSummary() {
        throw new MissingRestAddonException();
    }

    default ArtifactRetentionLinkModel getArchiveStorageLink() {
        throw new MissingRestAddonException();
    }

    default boolean isRetentionEnabled() {
        return false;
    }

    default void saveNamespaceAndMasterToken(String baseUrl, String exchangeUrl, String namespace, String tokenId,
            String accessToken, String tokenType, Long expiresIn, String scope) {
        throw new MissingRestAddonException();
    }

    default void markPolicyExecutionAsStopped(String policyKey, BasicStatusHolder statusHolder) {
        throw new MissingRestAddonException();
    }

    default AqlBase convertSearchCriteriaFormToAql(
            ArtifactRetentionPolicySearchCriteriaDescriptor searchCriteriaDescriptor) {
        throw new MissingRestAddonException();
    }

    default void updateMasterToken(String tokenId, String accessToken, String tokenType, Long expiresIn, String scope) {
        throw new MissingRestAddonException();
    }
}