package org.artifactory.version.converter.v3110;

import lombok.extern.slf4j.Slf4j;
import org.artifactory.version.converter.XmlConverter;
import org.artifactory.version.converter.v160.AddonsDefaultLayoutConverterHelper;
import org.jdom2.Document;
import org.jdom2.Element;
import org.jdom2.Namespace;

/**
 * For version 3.1.10
 * @author Rotem Kfir
 */
@Slf4j
public class AddCargoDefaultLayoutConverter implements XmlConverter {

    @Override
    public void convert(Document doc) {
        log.info("Starting 'Add Cargo default repository layout' conversion");
        Element rootElement = doc.getRootElement();
        Namespace namespace = rootElement.getNamespace();

        Element repoLayoutsElement = rootElement.getChild("repoLayouts", namespace);
        if (!alreadyExists(repoLayoutsElement)) {
            addCargoDefaultLayout(repoLayoutsElement, namespace);
        }
        log.info("Finished 'Add Cargo default repository layout' conversion successfully");
    }

    private boolean alreadyExists(Element repoLayoutsElement) {
        for (Element element : repoLayoutsElement.getChildren()) {
            boolean match = element.getChildren().stream()
                    .filter(e -> e.getName().equals("name"))
                    .anyMatch(e -> e.getContent().get(0).getValue().equals("cargo-default"));
            if (match) {
                return true;
            }
        }
        return false;
    }

    private void addCargoDefaultLayout(Element repoLayoutsElement, Namespace namespace) {
        repoLayoutsElement
                .addContent(AddonsDefaultLayoutConverterHelper.getRepoLayoutElement(repoLayoutsElement, namespace,
                        "cargo-default",
                        "crates/[module]/[module]-[baseRev].[ext]",
                        "false", null,
                        ".*",
                        ".*"));
    }
}