#!/usr/bin/env bash

set -e

export PROJECT_ROOT_DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")" && cd ../../.. && pwd)"
MODULES_TO_TEST="${MODULES_TO_TEST:-}"

function on_start() {
    cd "${PROJECT_ROOT_DIR}/artifactory-oss"
    local cache_dir="${run_dir}/${step_affinity_group}_cache_classes"
    local state_cache_dir="${PROJECT_ROOT_DIR}/artifactory-oss"
    local run_state_cache_dir="${cache_dir}/dir_cache"
    export MAVEN_PHASE="test"
    if pipeline_shouldRunSonar ; then
        MAVEN_PHASE="jacoco:prepare-agent surefire:test jacoco:report -Psonar"
    fi

    #export MVN_COMMAND="${MAVEN_PHASE} -P!frontend -pl ${MODULES_TO_TEST} -T 2 -Dartifactory.publish.artifacts=false -Denforcer.skip=true -Dcheckstyle.skip=true -Dmaven.resources.skip=true ${MAVEN_CONFIG}"
    export MVN_COMMAND="${MAVEN_PHASE} -P!frontend -T 2 -Dartifactory.publish.artifacts=false -Denforcer.skip=true -Dcheckstyle.skip=true -Dmaven.resources.skip=true ${MAVEN_CONFIG}"
    cd ${state_cache_dir}
    ${PROJECT_ROOT_DIR}/build/ci/scripts/javaGenerateConfig.sh
    if [ -d "${run_state_cache_dir}" ] && cp -r "${run_state_cache_dir}"/* "${state_cache_dir}" ; then
        echo "Dir state was restored." >&2
    fi
}

function on_complete() {
    ${PROJECT_ROOT_DIR}/build/ci/scripts/mvnCollectTestResults.sh artifactory-oss ./junittests
    save_tests ./junittests
}

function on_success() {
  if pipeline_shouldRunSonar ; then
    source "${PROJECT_ROOT_DIR}/build/ci/scripts/runSonarScannerGeneric.sh"
    sonar_storeCache "${PROJECT_ROOT_DIR}/artifactory-oss"
  fi
}
