/*
 *
 * Artifactory is a binaries repository manager.
 * Copyright (C) 2018 JFrog Ltd.
 *
 * Artifactory is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 * Artifactory is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with Artifactory.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

package org.artifactory.ui.rest.service.builds.buildsinfo;

import org.artifactory.api.build.BuildService;
import org.artifactory.projects.ProjectsService;
import org.artifactory.rest.common.service.ArtifactoryRestRequest;
import org.artifactory.rest.common.service.RestResponse;
import org.artifactory.rest.common.service.RestService;
import org.artifactory.ui.rest.model.builds.ProjectBuildsMetadata;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.config.BeanDefinition;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Component;

/**
 * @author BarakH
 */
@Component
@Scope(BeanDefinition.SCOPE_PROTOTYPE)
public class GetProjectBuildsMetadataService implements RestService {

    private static final Logger log = LoggerFactory.getLogger(GetProjectBuildsMetadataService.class);

    @Autowired
    private BuildService buildService;

    @Override
    public void execute(ArtifactoryRestRequest request, RestResponse response) {
        try {
            String projectKey = request.getPathParamByKey(ProjectsService.PROJECT_KEY);
            String buildRepoKey = buildService.getBuildInfoRepoKeyByProject(projectKey);
            int buildsCount = buildService.getBuildsCountByRepoKey(buildRepoKey);
            ProjectBuildsMetadata metadata = new ProjectBuildsMetadata(buildRepoKey, buildsCount);
            response.iModel(metadata);
        } catch (Exception e) {
            log.debug("", e);
            response.error("Failed to get build info repository name and number of builds: " + e.getMessage());
        }
    }
}
