package org.artifactory.ui.rest.model.admin.configuration.repository.info;

import edu.emory.mathcs.backport.java.util.Collections;
import org.artifactory.addon.AddonsManager;
import org.artifactory.addon.webstart.ArtifactWebstartAddon;
import org.artifactory.aol.AolService;
import org.artifactory.api.config.CentralConfigService;
import org.artifactory.api.context.ArtifactoryContextThreadBinder;
import org.artifactory.api.context.ContextHelper;
import org.artifactory.api.repo.RepositoryService;
import org.artifactory.common.home.ArtifactoryHome;
import org.artifactory.common.property.ArtifactorySystemProperties;
import org.artifactory.descriptor.config.CentralConfigDescriptor;
import org.artifactory.descriptor.repo.FederatedRepoDescriptor;
import org.artifactory.spring.ArtifactoryApplicationContext;
import org.artifactory.storage.binstore.service.BinaryService;
import org.mockito.Mock;
import org.mockito.MockitoAnnotations;
import org.testng.annotations.AfterMethod;
import org.testng.annotations.BeforeMethod;
import org.testng.annotations.DataProvider;
import org.testng.annotations.Test;

import java.util.List;

import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;
import static org.testng.Assert.assertEquals;
import static org.testng.Assert.assertTrue;

/**
 * Author: Ivan Perepelytsya
 * Date: 6/3/20.
 */
@Test
public class RepositoryFieldsValuesModelTest {

    @Mock
    private ArtifactoryApplicationContext artifactoryContext;
    @Mock
    private AddonsManager addonsManager;
    @Mock
    private ArtifactWebstartAddon artifactWebstartAddon;
    @Mock
    private CentralConfigDescriptor descriptor;
    @Mock
    private CentralConfigService centralConfigService;
    @Mock
    private ArtifactoryHome artifactoryHome;
    @Mock
    private ArtifactorySystemProperties artifactorySystemProperties;
    @Mock
    private AolService aolService;

    @Test
    public void testCdn() {
        final RepositoryService repositoryService = mock(RepositoryService.class);
        final BinaryService binaryService = mock(BinaryService.class);

        when(binaryService.isCdnAllowed()).thenReturn(true);
        when(descriptor.getProxies()).thenReturn(List.of());
        final RepositoryFieldsValuesModel model =
                new RepositoryFieldsValuesModel(descriptor, repositoryService, binaryService,
                        List.of("mvn", "npm", "nuget"));
        final List<String> allowedRedirects = model.getCdnRedirectAllowedRepos();

        assertEquals(allowedRedirects.size(), 3);
        assertEquals(allowedRedirects.get(0), "mvn");
        assertEquals(allowedRedirects.get(1), "npm");
        assertEquals(allowedRedirects.get(2), "nuget");
        assertTrue(model.isCdnAllowedPerRepo());

    }

    @Test
    public void testWithFederationRepos() {
        final BinaryService binaryService = mock(BinaryService.class);
        when(binaryService.isCdnAllowed()).thenReturn(true);

        final RepositoryService repositoryService = mock(RepositoryService.class);
        FederatedRepoDescriptor federatedRepoDescriptor = new FederatedRepoDescriptor();
        federatedRepoDescriptor.setKey("key");
        when(repositoryService.getFederatedRepoDescriptors()).thenReturn(List.of(federatedRepoDescriptor));
        final RepositoryFieldsValuesModel model =
                new RepositoryFieldsValuesModel(descriptor, repositoryService, binaryService,
                        List.of("mvn", "npm", "nuget"));
        List<String> availableFederatedRepos = model.getAvailableFederatedRepos();
        assertEquals(availableFederatedRepos.size(), 1);
        assertEquals(availableFederatedRepos.get(0), "key");
    }

    @Test(dataProvider = "skipDns")
    public void testDockerV1Enabled(boolean skipDns) {
        final RepositoryService repositoryService = mock(RepositoryService.class);
        final BinaryService binaryService = mock(BinaryService.class);
        when(descriptor.getProxies()).thenReturn(List.of());
        when(aolService.skipDockerDns()).thenReturn(skipDns);

        final RepositoryFieldsValuesModel model =
                new RepositoryFieldsValuesModel(descriptor, repositoryService, binaryService,
                        Collections.emptyList());
        assertEquals(!skipDns, model.isDockerV1Enabled());
    }

    @BeforeMethod
    public void setup() {
        MockitoAnnotations.initMocks(this);
        ArtifactoryContextThreadBinder.bind(artifactoryContext);

        ArtifactoryHome.bind(artifactoryHome);
        when(artifactoryHome.getArtifactoryProperties()).thenReturn(artifactorySystemProperties);

        when(addonsManager.addonByType(ArtifactWebstartAddon.class)).thenReturn(artifactWebstartAddon);
        when(artifactWebstartAddon.getKeyPairNames()).thenReturn(List.of());
        when(ContextHelper.get().beanForType(AddonsManager.class)).thenReturn(addonsManager);
        when(ContextHelper.get().beanForType(CentralConfigService.class)).thenReturn(centralConfigService);
        when(centralConfigService.getDescriptor()).thenReturn(descriptor);
        when(artifactoryContext.beanForType(AolService.class)).thenReturn(aolService);
        when(aolService.skipDockerDns()).thenReturn(false);
    }

    @AfterMethod
    private void cleanup() {
        ArtifactoryContextThreadBinder.unbind();
        ArtifactoryHome.unbind();
    }

    @DataProvider
    private Object[][] skipDns() {
        return new Object[][] {{true}, {false}};
    }
}