package org.artifactory.ui.rest.service.admin.advanced.storagesummary;

import org.artifactory.projects.ProjectsService;
import org.artifactory.rest.common.service.ArtifactoryRestRequest;
import org.artifactory.rest.common.service.ArtifactoryRestResponse;
import org.artifactory.storage.StorageService;
import org.artifactory.storage.StorageSummaryInfo;
import org.artifactory.ui.rest.model.storage.ProjectStorageUsage;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;
import org.mockito.Mock;
import org.mockito.Mockito;
import org.mockito.MockitoAnnotations;

import java.util.List;
import java.util.Map;

public class GetUIProjectsStorageUsageTest {

    private final static String TEST_PROJECT = "pkey";
    private final static String TEST_PROJECT_NAME = "The Project";
    @Mock
    private StorageService storageService;
    @Mock
    private ProjectsService projectsService;

    private GetUIProjectsStorageUsage getUIProjectsStorageUsage;

    @Before
    public void setUp() {
        MockitoAnnotations.openMocks(this);
        getUIProjectsStorageUsage = Mockito.spy(new GetUIProjectsStorageUsage());
        getUIProjectsStorageUsage.setProjectsService(projectsService);
        getUIProjectsStorageUsage.setStorageService(storageService);

        Map<String, Long> projectsTotalSizes = Map.of(TEST_PROJECT, 1000L);
        StorageSummaryInfo storageSummaryInfo = new StorageSummaryInfo(Map.of(), null, projectsTotalSizes, Map.of());
        Mockito.when(storageService.getStorageSummaryInfoFromCache()).thenReturn(storageSummaryInfo);
        Mockito.when(projectsService.getAllProjectsManagedByUser()).thenReturn(List.of(ProjectsService.DEFAULT_PROJECT,
                TEST_PROJECT));
        Mockito.when(projectsService.getProjectStorageQuotaBytes(TEST_PROJECT)).thenReturn(10000L);
        Mockito.when(projectsService.getProjectDisplayName(TEST_PROJECT)).thenReturn(TEST_PROJECT_NAME);
    }

    @Test
    public void testGetUIProjectsStorageUsageTest() {
        ArtifactoryRestRequest restRequest = Mockito.mock(ArtifactoryRestRequest.class);
        ArtifactoryRestResponse response = new ArtifactoryRestResponse();

        getUIProjectsStorageUsage.execute(restRequest, response);
        List<ProjectStorageUsage> results = (List<ProjectStorageUsage>) response.getIModel();
        Assert.assertEquals(1, results.size());
        ProjectStorageUsage projectStorageUsage = results.get(0);
        Assert.assertEquals(TEST_PROJECT, projectStorageUsage.getProjectKey());
        Assert.assertEquals(TEST_PROJECT_NAME, projectStorageUsage.getProjectName());
        Assert.assertEquals(1000, projectStorageUsage.getUsedStorageBytes());
        Assert.assertEquals(10000, projectStorageUsage.getStorageLimitBytes());
    }
}