package org.artifactory.ui.rest.service.admin.configuration.general;

import org.artifactory.api.config.CentralConfigService;
import org.artifactory.descriptor.config.MutableCentralConfigDescriptor;
import org.artifactory.service.ConfigValidationService;
import org.artifactory.ui.rest.model.admin.configuration.generalconfig.GeneralConfig;
import org.jetbrains.annotations.NotNull;
import org.mockito.Mockito;
import org.testng.Assert;
import org.testng.annotations.Test;

import static org.artifactory.ui.rest.service.admin.configuration.general.UpdateConfigUtils.prepareAddonsManager;
import static org.artifactory.ui.rest.service.admin.configuration.general.UpdateConfigUtils.prepareMutableCentralConfigDescriptor;

/**
 * @author Alexei Vainshtein
 */
public class UpdateGeneralConfigServiceTest {

    @Test
    public void testUpdateDescriptorAndSave() {
        MutableCentralConfigDescriptor descriptor = prepareMutableCentralConfigDescriptor();
        CentralConfigService testCentralConfigService = Mockito.mock(CentralConfigService.class);
        Mockito.when(testCentralConfigService.getMutableDescriptor()).thenReturn(descriptor);
        UpdateGeneralConfigService service =
                new UpdateGeneralConfigService(testCentralConfigService, prepareAddonsManager(),
                        new ConfigValidationService());
        Mockito.doAnswer(invocationOnMock -> {
            MutableCentralConfigDescriptor mutableCentralConfigDescriptor =
                    (MutableCentralConfigDescriptor) invocationOnMock.getArguments()[0];
            Assert.assertTrue(mutableCentralConfigDescriptor.isArchiveIndexEnabled());
            return null;
        }).when(testCentralConfigService).saveEditedDescriptorAndReload(descriptor);
        service.updateDescriptorAndSave(prepareGeneralConfig());
    }

    @NotNull
    public GeneralConfig prepareGeneralConfig() {
        GeneralConfig config = new GeneralConfig();
        config.setArchiveIndexEnabled(true);
        config.setHelpLinksEnabled(true);
        config.setFileUploadMaxSize(10);
        config.setShowAddonSettings(false);
        config.setGlobalOfflineMode(true);
        config.setSystemMessageEnabled(false);
        config.setShowSystemMessageOnAllPages(false);
        config.setFolderDownloadEnabled(false);
        config.setFolderDownloadEnabled(false);
        return config;
    }
}